@@ -57,10 +57,16 @@ function(model, sigma.estimated, analytic) {
     }
   }
   
-  Rchol   <- chol(B)
-  L1      <- backsolve(Rchol, C, transpose = TRUE)
-  Lambday <- backsolve(Rchol, L1)
-
+  Lambday <- try(solve(B) %*% C)
+  
+  if(class(Lambday)=="try-error"){  
+  
+    Rchol   <- try(chol(B))
+    L1      <- backsolve(Rchol, C, transpose = TRUE)
+    Lambday <- backsolve(Rchol, L1)
+    
+  }
+  
   df <- model$n - sum(diag(A))
   for (j in 1:length(model$theta)) {
       df <- df + sum(Lambday[j,] %*% (A %*% (model$Wlist[[j]] %*% e)))  
